@@ -2,7 +2,7 @@ package Shipwright;
 
 use warnings;
 use strict;
-use version; our $VERSION = qv('2.3.5');
+use version; our $VERSION = qv('2.4.0');
 
 use base qw/Class::Accessor::Fast/;
 
@@ -10,9 +10,6 @@ __PACKAGE__->mk_accessors(qw/backend source build log_level log_file/);
 
 use Shipwright::Logger;
 use Shipwright::Util;
-use Shipwright::Backend;
-use Shipwright::Source;
-use File::Temp qw/tempfile/;
 use File::Spec::Functions qw/catfile tmpdir/;
 
 sub new {
@@ -39,10 +36,12 @@ sub new {
     Shipwright::Logger->new($self);
 
     if ( $args{repository} ) {
+        require Shipwright::Backend;
         $self->backend( Shipwright::Backend->new(%args) );
     }
 
     if ( $args{source} ) {
+        require Shipwright::Source;
         $self->source( Shipwright::Source->new(%args) );
     }
 
